@@ -1,20 +1,15 @@
-from collections import defaultdict
-
 import tqdm
 
-from oireachtas_data.utils import iter_debates
-
+from oireachtas_nlp.utils import get_speaker_para_map
 from oireachtas_nlp import logger
 from oireachtas_nlp.word_usage.base_word_usage import BaseWordUsage
 
 
 class MemberWordUsage(BaseWordUsage):
+
     def process(self):
-        speaker_map = defaultdict(list)
         logger.info("Getting words")
-        for debate in tqdm.tqdm(iter_debates()):
-            for speaker, paras in debate.content_by_speaker.items():
-                speaker_map[speaker].extend(paras)
+        speaker_map = get_speaker_para_map()
 
         logger.info("Processing words")
         for speaker, paras in tqdm.tqdm(speaker_map.items()):
